#
# spec file for package rofi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rofi
Version:        1.7.8
Release:        1.1
Summary:        A window switcher, run dialog and dmenu replacement
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/davatorium/rofi
Source:         https://github.com/davatorium/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Patch0:         xdg-terminal.patch
# Required version 0.11 is not yet in TW BuildRequires:  check-devel
BuildRequires:  bison
BuildRequires:  cairo-devel
BuildRequires:  flex >= 2.5.39
BuildRequires:  glib2-devel >= 2.36
BuildRequires:  libjpeg8-devel
BuildRequires:  librsvg-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  libxkbcommon-x11-devel
BuildRequires:  make
BuildRequires:  pango-devel
BuildRequires:  startup-notification-devel
BuildRequires:  xcb-util-cursor-devel
BuildRequires:  xcb-util-devel
BuildRequires:  xcb-util-keysyms-devel
BuildRequires:  xcb-util-wm-devel
BuildRequires:  xcb-util-xrm-devel
Requires:       xdg-utils
# To allow coexistence with rofi-wayland
Conflicts:      rofi-wayland
Provides:       rofi-launcher

%description
rofi is a popup window switcher roughly based on "superswitcher",
requiring only xlib and pango. This version started off as a clone of
simpleswitcher, the version from Sean Pringle. Rofi developed extra
features, like a run dialog, SSH launcher and can act as a drop-in
dmenu replacement.

%package devel
Summary:        Development files for rofi
Group:          Development/Libraries/C and C++

%description devel
Development files and headers for rofi

%prep
%autosetup -p1

%build
sed -i "s|%{_bindir}/env bash|/bin/bash|g" ./script/rofi-sensible-terminal
sed -i "s|%{_bindir}/env bash|/bin/bash|g" ./script/rofi-theme-selector
%configure --disable-check
%make_build

%install
%make_install

%files
%license COPYING
%doc Changelog README.md
%{_bindir}/rofi
%{_bindir}/rofi-sensible-terminal
%{_bindir}/rofi-theme-selector
%dir %{_datadir}/rofi/
%{_datadir}/rofi/themes/
%{_datadir}/applications/rofi-theme-selector.desktop
%{_datadir}/applications/rofi.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/rofi.svg
%{_mandir}/man1/rofi.1%{?ext_man}
%{_mandir}/man1/rofi-sensible-terminal.1%{?ext_man}
%{_mandir}/man1/rofi-theme-selector.1%{?ext_man}
%{_mandir}/man5/rofi-theme.5%{?ext_man}
%{_mandir}/man5/rofi-script.5%{?ext_man}
%{_mandir}/man5/rofi-dmenu.5%{?ext_man}
%{_mandir}/man5/rofi-keys.5%{?ext_man}
%{_mandir}/man5/rofi-debugging.5%{?ext_man}
%{_mandir}/man5/rofi-thumbnails.5%{?ext_man}

%files devel
%{_includedir}/rofi/
%{_libdir}/pkgconfig/rofi.pc

%changelog
* Sun Jan 19 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.7.8:
  * Fix drawing issue
    In the last release we had some code that hit a bug in some
    graphics drivers. #2076
  * DBusActivatable
    The previously introduced DBusActivatable seems to cause
    some issues and confusion. #2077
  * CI Fixes
  * See https://github.com/davatorium/rofi/releases/tag/1.7.8
    for details
* Tue Jan  7 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.7.7:
  * Fix drawing issue #2068
  * Fix window mode missing some windows #2071
  * Fix character in config file broken #2070
  * Resolve 'rasinc' for @imports #2069
  * Desktop file DBus activation #1924
  * Resolve -config identical to -theme #2040
* Fri Dec 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.7.6:
  * Recursive file browser
  * Copy to clipboard support
  * Entry box history
  * Fix calc
  * Text and cursor outline
  * Other smaller changes
  * For details see:
    https://github.com/davatorium/rofi/releases/tag/1.7.6
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Oct 31 2022 Matej Cepl <mcepl@suse.com>
- Add rofi-launcher provides to allow coexistence with
  rofi-wayland.
* Mon Aug 22 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.7.5:
  * In DMenu sync mode, the separator is left in the string.
  * On special crafted delayed input in dmenu it shows updates to the
    list very slow.
    It now forces to push update (if there) every 1/10 of a second.
  * In the view some of the update/redraw policies are fixed to reduced
    the perceived delay.
* Mon Aug 15 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.7.4:
  * [Doc] Add -config to -help output. (#1665)
  * [Dmenu] Fix multi-select, use text as indicator.
  * [filebrowser] Fix building on Mac. (#1662,#1663)
  * [textbox] Implement text-transform option. (#1010)
  * [script] Add new-selection (#1064).
  * [Script] Add keep-selection flag that keeps the current selection. (#1064)
  * [Debug] Add '-log' flag to redirect debug output to a file.
  * [XCB] Try to deduce rotated monitors.
  * [Doc] Add rofi-dmenu to 'See also' in rofi(1).
  * [Options] Mark offset(s) as deprecated.
  * [Modes] Support loading multiple icon sizes.
  * [View] Add textbox|icon-current-entry widget.
  * [Doc] Add ascii manpage to rofi-script(5).
  * [Script] Print user-scripts in -h
  * [Script] Look into $XDG_CONFIG_HOME/rofi/scripts/ for user scripts.
  * [Dmenu|Script] Allow (some) theme modification from script/dmenu.
  * [Textbox] Fix some pango alignment.
  * [FileBrowser] Bind 'kb-accept-custom-alt' to directory up.
  * [Build] Add desktop files as per complaint (rofi theme selector and rofi itself).
  * [Dmenu] Code cleanups.
  * [Themes] Remove broken themes.
  * [Modes] Allow fallback icon per mode. (#1633)
  * [View] Fix broken anchoring behaviour. (#1630)
  * [Rofi] Move error message on commandline to UI.
  * [Listview] Option to hide listview elements when not filtered. (#1622,#1079)
  * [DMenu] Speed up reading async in of large files from stdin.
  * [FileBrowser] Make accept-alt open folder if selected.
  * [Helper] Add XDG_DATA_DIRS to the theme search path. (#1619)
  * [Doc] Split up manpages and extend them with examples.
  * [Doc] Highlight use of -dump-config in config. (#1609)
  * [Config] Workaround for in data type passed to string option.
  * [Listview] Allow flow of elements to be set. (#1058)
  * [Script] Add data field that gets passed to next execution. (#1601)
  * Change modi to modes to avoid confusion.
  * [Theme] When links are unresolvable throw an error to the user.
  * [DMenu] Document the display-columns and display-column-separator option.
  * [Theme] Media now supports enabled that supports an environment variable.
  * [IconFetcher] Support rendering fonts as icon.
  * [xcb] Remove work-around to fix use with new xkeyboard-config (#1642)
  * For details see https://github.com/davatorium/rofi/releases/tag/1.7.4
- Update xdg-terminal.patch
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop cppcheck BuildRequires: it would only be used when
  explicitly calling make cppcheck (which is not done;
  additionally, cppcheck does not exist on all arches anymore)
* Tue Feb  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.7.3:
  * [Help] Print out the parsed config/theme files in -help output.
  * [Keybindings] Fix keybindings being modified by -theme-str
  * [Doc] Add rofi-dmenu manpage.
  * [XCB] Cache lookup of monitor.
  * Add -replace option (#568)
  * Fix memory leak.
  * [1566] Add extra debug for resolving monitors.
  * [Theme] Add round,floor,ceil function in @calc (#1569)
  * [Doc] Explain icon lookup.
  * [Combi] Add -combi-display-format (#1570)
  * [Theme] Expand list type ([]) for more data types.
  * [Theme] Add support for tab-stops on textbox. (#1571)
  * [Theme] Testing direct access to widgets via cmdline
    option (-theme+widget+property value)
* Mon Dec  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.7.2:
  * [Build] Fix building without window mode enabled.
  * [Config] Do not print out the 'theme' field in configuration on dump.
  * [CI] test window mode less build.
  * Allow configuration block in theme again.
- Remove fix-shebangs.patch
* Mon Dec  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * [Theme] Fix highlight with only theme.
  * Updated documentation and landing page (Thanks to RaZ0rr-Two)
  * [Combi] Fix nesting combi modi (#1510)
  * [DMenu] Fix crash dmenu mode when no entry is available. (#1504)
  * [Run|Drun] Only initialize file-completer on first use.
  * [FileBrowser] Reduce number of re-allocs.
  * [Readme] Remove generating readme.html for dist.
  * [Dmenu] Fix uninitialized memory (non-selectable)
  * [FileBrowser] Try to convert invalid encoded text. (#1471)
  * [FileBrowser] Don't crash on invalid file filenames. (#1471)
  * [Theme] print known colors as its color name.
  * [CMD] If failed to convert commandline to new option, do not stop. (#1425)
  * [Theme] Fix parsing of nested media blocks. (#1442)
  * [Widgets] Fix sizing logic widgets. (#1437)
  * [Window] Try to fix auto-sizing of desktop names for non-i3 desktops. (#1439)
  * [Window] Fix broken close-on-delete. (#1421)
  * [Listview] Correctly check if selected item is highlighted. (#1423)
  * [Entry] Allow action to be taken on input change. (#1405)
  * [Theme] Don't truncate double values. (#1419)
  * [Grammar] Add support for env(ENV,default).
  * [Documentation] documentation fixes.
  * [Theme] fix dmenu theme ( #1396).
* Sun Nov 22 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to 1.6.1:
  * resolving issues that the default theme had on some systems
  * [Theme] Add min/max operator support to calc()
  * [Theme] @media statements can now be nested
  * FileBrowser: the file browser plugin is now integrated
  * Use GdkPixbuf for Icon parsing
  * Fix parsing dicts in config file (with " in middle of string)
  * Add -normalize-match option, that tries to o match ö, é match e
  * Show error message and return to list instead of closing
  * [Textbox] Try to fix estimated font height
  * [DRun] Fix crash in broken caching mechanism
* Mon Sep  7 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.6.0:
  * Add themes/ directory in the users rofi config directory to the
    theme search path. (#1001)
  * Split listview element into box widget holding icon and textbox.
    Supporting more dynamic themes. (#949)
  * Fix default theme.
  * Add -upgrade-config option.
  * Add ROFI_PLUGIN_PATH variable.
  * Add check for running rofi inside a Script mode.
  * Remove gnome-terminal from rofi-sensible-terminal (#1074)
  * Set window title based on mode name. (#969)
  * Subpixel rendering workaround. (#303)
  * Support character type in configuration {} block . (#1131)
  * Use XDG_CONFIG_DIRS (#1133)
  * [Box] Bug fix update propagation.
  * [Build] Fix meson build with meson 0.55.
  * [DMenu] Add -keep-right flag. (#1089)
  * [DMenu] Don't match markup when filtering. (#579,#1128)
  * [DRUN] Support Type=Link (#1166)
  * [DRun] Add %% to escape variable.
  * [DRun] Add an optional cache for desktop files. (#1040)
  * [DRun] Add keywords as default match item. (#1061)
  * [DRun] Don't run custom commands.
  * [DRun] Match keywords field.
  * [DRun] Only show selected categories. (#817)
  * [Dmenu|Script] Add non-selectable entries. (#1024)
  * [Doc] Update documentation.
  * [IconFetcher] Add jpeg support.
  * [Icon] Set default size to 1.2 CH.
  * [Icon] support distance for size.
  * [Listview] Add widget to show keybinding index. (#1050)
  * [Listview] Fix distribution of remaining space.
  * [Listview] Fix left-to-right scrolling. (#1028)
  * [Listview] Fix updating elements. (#1032)
  * [Matching] Make Fuzzy matching non greedy.
  * [Script] Add delimiter option. (#1041)
  * [Script] Add environment variable indicating state.
  * [Script] Add extra matchign field (meta). (#1052)
  * [Script] Add info option, hidden field that gets passed
    to script via ROFI_INFO environment.
  * [Script] Add no-custom option.
  * [Textbox] Add cursor blinking option.
  * [Textbox] Add placeholder. (#1020)
  * [Theme] Add calc() support. (#1105)
  * [Theme] Add alpha channel to highlight color. (#1033)
  * [Theme] Add sidebar as mode-switcher alias.
  * [Theme] Add some initial @media support. (#893)
  * [Theme] Support buttons in the UI.
  * [View] Add two widgets. One showing number of rows,
    other number of filtered rows. (#1026)
  * [Window] Add window thumbnail option.
  * [Window] Remove arbitrary # window limit. (#1047)
  * [Window] check buffer overflow.
  * See https://github.com/davatorium/rofi/releases/tag/1.6.0
    for more details
- Update xdg-terminal.patch
* Mon Jul  1 2019 mvetter@suse.com
- Update to version 1.5.4:
  * Fix crash in SSH dialog
* Mon Jun 24 2019 mvetter@suse.com
- Update to version 1.5.3:
  * Sidebar renamed to mode-switcher
  * Icons in dmenu
  * Ellipsizing listview entries
  * Update manpage with missing entry. (#937)
  * Rename sidebar widget to mode-switcher and allow configuration from theme.
  * Timing: Moving timing output to glib debug system.
  * SSH: Fix unitialized variable issue.
  * SSH: resolve ':' conflict in history entries.
  * SSH: be case-insensitive when parsing keywords.
  * RASI Lexer: Fix nested () in variable default field.
  * USABILITY: When mode not found, show in gui not just on commandline.
  * ICON: Allow aligning image in icon widget.
  * Meson build system: cleanups and improvements.
  * Meson build system: add documentation (#943)
  * Window: Fix default formatting and remove (invalid) deprecation warning.
  * DMenu: Add support for showing icons infront of displayed list.
  * Overlay: Fix overlay widget to correctly integrate in new theme format.
  * Update libnkutils, libgwater.
  * DMENU: Add format option to strip pango markup from return value.
  * ListView: allow user to change ellipsizing displayed value at run-time.
- Update xdg-terminal.patch
* Sun Dec 30 2018 mvetter@suse.com
- Update to version 1.5.2:
  * Clearify Check dependency. (#879)
  * Add option to change negate character. (#877)
  * Fix assert and update test. (#875)
  * Add missing example Script (#869)
  * Add drun-display-format option. (#858)
  * Fixing typos (#867,#837,#831,#804)
  * Fix loading icons that are in cache (#860)
  * Improve ssh known_host parser. (#820)
  * Add terminals to rofi-sensible-terminal (#808)
  * Lexer Fix several ambiguity and handling of empty input.
  * IconFetcher preload the user set icon theme.
  * IconFetcher use generic threadpool.
  * Lexer support environment variables.
  * Cleanup syntax for sorting. (#816)
  * Documents update.
  * Fix how borders are drawn. (#792, #783)
* Sun Mar 18 2018 avindra@opensuse.org
- Update to version 1.5.1
  * [SSH] Reload when ssh entry is deleted.
  * Add support for randr 1.5 monitors.
  * Fix border layout structure.
  * Fix make test in libnkutils.
  * Fix typos in theme manpage.
  * Fix README config file location.
- cleanup with spec-cleaner
* Thu Feb  1 2018 avindra@opensuse.org
- Update to version 1.5.0:
  * New features
    + Specify matching field
    + Pass extra properties in script mode
    + Negated matching
  * Backwards incompatible changes:
    + All Mouse buttons and scroll bindings Prompt colon have more
    semantic names
  * Changes
    + Prompt colon is now removed by default
    + In themes the '#' prefix before the element name is now
    optional
  * For full details, see:
    https://github.com/DaveDavenport/rofi/releases/tag/1.5.0
- switch to xz tarball
- rebase xdg-terminal.patch
- add fix-shebangs.patch
- spec file tidiness:
  - use valid group for devel package
  - remove unnecessary build dependencies
  - remove explicit prefix for "devel" packages
* Sun Oct 15 2017 mvetter@suse.com
- Update to version 1.4.2:
  * Add sort to manpage. (#682[1])
  * Add tranaparent to theme manpage. (#688[2])
  * Re-add theme headers. (#679[3])
  * Fix super key. (#684[4])
  * Unknown option libnkutils:uuid. (#677[5])
  * Mode window is not found. (#686[6])
  * Fix meson build in dist file.
* Wed Sep 27 2017 mvetter@suse.com
- Update to version 1.4.1:
  * Improved error messages
  * Customizable highlight, allowing underline, strikethrough,
    italic, bold, small caps and the color to be set.
  * Give up when keyboard is not grabbed in first 5 seconds.
  * Improve manpage
  * Super-{1..10} hotkeys for selecting the first 10 rows.
  * Allow x-align/y-align on textbox.
  * Support matching bangs on multiple characters in combi mode. (#542)
  * Set WM_CLASS (#549)
  * Async pre-read 25 rows for improving user experience. (#550)
  * Improve handling in floating window manager by always setting window size.
  * DRun speedups.
  * Make lazy-grab default.
  * Remove extra layer in textbox. (#553)
  * Ignore fonts that result in a family name or size 0. (#554)
  * [Combi] Allow bang to match multiple modes. (#552)
  * Add detection of window manager and work around quirks.
  * Support dynamic plugins.
  * DMENU tty detection.
  * Support for icons in drun, combi and window mode.
  * Startup notification of launched application support.
  * Meson support.
  * Fuzzy matching with fzf based sorting algorithm.
  * Auto-detect DPI.
  * Set cursor at the end of the input field. (#662)
  * Meson support (thx to SardemFF7).
  * [Script] parse the command as if it was commandline. (#650)
  * Don't enable asan by meson. (#642)
  * Allow text widgets to be added in theme and string to be set.
  * [Dmenu] Support the -w flag.
  * Allow window (via window id) to be location for rofi window.
  * [Dmenu] Allow multi-select mode in -no-custom mode.
  * Flex/Bison based parser for new theme format.
  * Meson build support.
  * Initial plugin support, exporting of pkg-config file for rofi.
  * Improved positioning support for placing window on monitor.
  * Allow rofi to be placed above window based on window id.
  * Support different font per textbox.
- Update xdg-terminal.patch
- Still use automake due to
  https://github.com/DaveDavenport/rofi/issues/677
- Don't use 'check' yet because 0.11 is not yet in TW
* Thu Feb  2 2017 jengelh@inai.de
- Trim description
* Wed Jan 11 2017 mvetter@suse.com
- Update to version 1.3.1:
  New Features
  * [DRun] Search categories. (#449)
  Improvements
  * Fix exit when failed to grab keyboard. (#524)
  * Introduce lazy keyboard grab mode for people who want rofi to show on key-down in i3.
  * Add copyrights to theme (needed for debian packaging).
  * DMENU: Correctly detect end-of-file (#518)
  * Directly queue redraw on overlay change.
  * Remove pango markup from workspace names in I3. (#507)
* Wed Sep  7 2016 mvetter@suse.com
- Update to version 1.2.0:
  New Features
  * Highlight matched part of the string.
  * Make window switcher string customizable.
  Improvements
  * Improved selection mode in dmenu with selection counter.
  * Improved selection mode with 'dot' indicator.
  * Fix Current Desktop window switcher.
  * Fix  launching in terminal.
  * Supports include in config.
  * Add Control+k remove till eol keybinding.
  * Change clear line to Control+w and make Control+u remove till sol (matching readline)
  * Track origin of option value e.g. who set the option.
  * Comment default values in dump-xresources.
  * Fix displaying on 30bit 10bpc X setup.
  Removals:
  * Remove xlib dependency (xcb-xrm)
  * Remove fuzzy option
  * Remove i3 workaround as it no longer needed since I3 v4.9. (Feb. 2015)
- Remove BuildRequire xorg-x11-devel in favour of xcb-util-xrm-devel
* Thu Jun 16 2016 mvetter@suse.com
- Fix typo in xdg-terminal.patch
* Thu Jun 16 2016 mvetter@suse.com
- Update to version 1.1.0:
  New Features
  * Keys mode, showing keybindings.
  * Stop cycling option (#407) (Thx to Yaroslav)
  * Kill window on delete entry (#316)
  Improvements
  * Add Control+Backspace as remove word back keybinding.
  * Allow user to use X11 background for fake transparency (#390)
  * Allow user to specify background image.
  * Improved keybinding handling, allowing on-release and modifier only (#384).
  * Use display name for prompt (#409)
  * Parse subdirectories in drun parser (#416)
  * Switch to stop cycling (#407)
  Bug fixes
  * Grab mouse pointer with keyboard
- Update xdg-terminal.patch to match
* Thu May 12 2016 mvetter@suse.com
- Update to version 1.0.1
  * Fix typo in manpage.
  * Return old behaviour for rofi placement (#395, #389)
  * Switch desktop when switching window (#393)
  * Remove unneeded use of bash (#391)
  * Make history parser more robust against corrupted files. (#388)
  * Fix desktop number (#386)
* Tue Apr 19 2016 mvetter@suse.com
- Update to version 1.0.0
- Uses xcb instead of xlib now
    New Features:
  * Blinking cursor
  * Separate configuration file
  * History in drun mode (#343)
  * Context menu mode, show rofi at the mouse pointer
    Improvement:
  * auto select and single item on dmenu mode (#281)
  * Unlimited window title length.
  * Correctly follow the active desktop, instead of active window.
  * If requesting modi that is not enabled, show it anyway.
  * DMenu password mode. (#315)
  * Levenshtein sort is now UTF-8 aware.
  * Use xcb instead of large xlib library.
  * Use GLib mainloop for cleaner code and easier external event based handling in future.
  * Run dialog: Try to convert between locale, fs encoding and utf8. Fixing problems with non-utf8 filesystem encodings.
  * Try to display non-utf8 strings as good as possible.
  * Autocomplete bang hint in combi mode (#380)
  * Remove magic line length limits by switching to getline from fgets.
  * Print git version for git builds in version string.
  Bug fixes:
  * Fix subpixel rendering. (#303)
  * Fix basic tests on OpenBSD (#272)
  * Fix wrong use of memcpy (thx to Jasperia).
  * Work around for sigwaitinfo on OpenBSD.
  * Ignore invalid entries (non-utf8) in dmenu mode.
  * Glib signal handling.
  * Fix connecting to i3 on bsd.
  * Be able to distinguish between empty and cancel in dmenu mode. (#323)
  * Fix memcpy on single memory region. (#312)
  * Fix opening file with mode a+ and using fseek to overwrite on bsd.
  Regressions
  * Removal of old themeing method. Given it was incomplete.
  * Removal of daemon mode, given this duplicates Window Manager functionality.
* Mon Mar  7 2016 mvetter@suse.com
- Update to version 0.15.12
  * keyboard layout bugfixes
  * speedups for dmenu reading
  * multi core
  * better themes support
  * a lot more
- Remove 0001-Replace-x-terminal-emulator-with-xdg-terminal.patch:
  and add xdg-terminal.patch: using xdg-terminal
* Tue Aug  4 2015 mvetter@suse.com
- Add patch 0001-Replace-x-terminal-emulator-with-xdg-terminal.patch
  to use xdg-terminal instead of x-terminal-emulator.
* Tue Jul 28 2015 mvetter@suse.com
- Initial package for version 0.15.7.
